=========
Darkseed_
=========

.. image:: https://travis-ci.org/blackforestbotanics/darkseed.svg?branch=master
   :target: https://travis-ci.org/blackforestbotanics/darkseed
   :alt: travis-link
.. image:: https://codecov.io/gh/blackforestbotanics/darkseed/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/blackforestbotanics/darkseed
   :alt: codecov-link
.. image:: https://img.shields.io/pypi/v/darkseed.svg
   :target: https://pypi.org/project/darkseed/
   :alt: pypi-link

The `Pelican <https://github.com/getpelican/pelican>`_ theme for the Botanixxx_ (`src <https://github.com/blackforestbotanics/botanixxx>`_) blog.

.. _darkseed: https://github.com/blackforestbotanics/darkseed
.. _botanixxx: https://botanixxx.com

installing via `Pip <https://github.com/pypa/pip>`_ or `Pipenv <https://github.com/pypa/pipenv>`_:

.. code:: bash

  pip install darkseed

  # or

  pipenv install darkseed

local development:

.. code:: bash

  cd ~/projects
  git clone git@github.com:blackforestbotanics/darkseed.git
  cd <your blog>
  pelican -t ../darkseed

License
-------

MIT
